@@ -7,15 +7,19 @@ import HoleAttributesEditor from './hole-attributes-editor';
 export default function AttributesEditor(_ref) {
   var element = _ref.element,
       onUpdate = _ref.onUpdate,
-      attributeFormData = _ref.attributeFormData;
+      attributeFormData = _ref.attributeFormData,
+      state = _ref.state;
 
   switch (element.prototype) {
     case 'items':
-      return React.createElement(ItemAttributesEditor, { element: element, onUpdate: onUpdate, attributeFormData: attributeFormData });
+      return React.createElement(ItemAttributesEditor, { element: element, onUpdate: onUpdate, attributeFormData: attributeFormData,
+        state: state });
     case 'lines':
-      return React.createElement(LineAttributesEditor, { element: element, onUpdate: onUpdate, attributeFormData: attributeFormData });
+      return React.createElement(LineAttributesEditor, { element: element, onUpdate: onUpdate, attributeFormData: attributeFormData,
+        state: state });
     case 'holes':
-      return React.createElement(HoleAttributesEditor, { element: element, onUpdate: onUpdate, attributeFormData: attributeFormData });
+      return React.createElement(HoleAttributesEditor, { element: element, onUpdate: onUpdate, attributeFormData: attributeFormData,
+        state: state });
     case 'areas':
       return null;
 
@@ -27,5 +31,6 @@ export default function AttributesEditor(_ref) {
 AttributesEditor.propTypes = {
   element: PropTypes.object.isRequired,
   onUpdate: PropTypes.func.isRequired,
-  attributeFormData: PropTypes.object.isRequired
+  attributeFormData: PropTypes.object.isRequired,
+  state: PropTypes.object.isRequired
 };
\ No newline at end of file
