@@ -24,6 +24,7 @@ export var THROW_ERROR = 'THROW_ERROR';
 export var THROW_WARNING = 'THROW_WARNING';
 export var COPY_PROPERTIES = 'COPY_PROPERTIES';
 export var PASTE_PROPERTIES = 'PASTE_PROPERTIES';
+export var PUSH_LAST_SELECTED_CATALOG_ELEMENT_TO_HISTORY = 'PUSH_LAST_SELECTED_CATALOG_ELEMENT_TO_HISTORY';
 
 // ACTIONS viewer2D
 export var SELECT_TOOL_ZOOM_IN = 'SELECT_TOOL_ZOOM_IN';
@@ -107,7 +108,8 @@ export var PROJECT_ACTIONS = {
   THROW_ERROR: THROW_ERROR,
   THROW_WARNING: THROW_WARNING,
   COPY_PROPERTIES: COPY_PROPERTIES,
-  PASTE_PROPERTIES: PASTE_PROPERTIES
+  PASTE_PROPERTIES: PASTE_PROPERTIES,
+  PUSH_LAST_SELECTED_CATALOG_ELEMENT_TO_HISTORY: PUSH_LAST_SELECTED_CATALOG_ELEMENT_TO_HISTORY
 };
 
 export var VIEWER2D_ACTIONS = {
