@@ -1,12 +1,20 @@
 import React, {Component} from 'react';
 import PropTypes from 'prop-types';
 import PropertyLengthMeasure from '../../../../catalog/properties/property-lenght-measure';
+import PropertyString from '../../../../catalog/properties/property-string';
 
 export default function HoleAttributesEditor({element, onUpdate, attributeFormData, state}, {translator}) {
+  let name = attributeFormData.has('name') ? attributeFormData.get('name') : element.name;
   let offsetA = attributeFormData.has('offsetA') ? attributeFormData.get('offsetA') : element.offsetA;
   let offsetB = attributeFormData.has('offsetB') ? attributeFormData.get('offsetB') : element.offsetA;
 
   return <div>
+    <PropertyString
+      value={name}
+      onUpdate={mapped => onUpdate('name', mapped)}
+      configs={{label: 'Nome'}}
+      state={state}
+    />
     <PropertyLengthMeasure
       value={offsetA}
       onUpdate={mapped => onUpdate('offsetA', mapped)}
